'use strict';

exports.__esModule = true;

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _digiratiAnnotationRedux = require('digirati-annotation-redux');

var _digiratiAnnotationComponents = require('digirati-annotation-components');

var _ComboButton = require('digirati-annotation-components/es/components/inputs/ComboButton');

var _ComboButton2 = _interopRequireDefault(_ComboButton);

var _manifestQuery = require('digirati-annotation-redux/es/query/manifestQuery');

var _annotations = require('digirati-annotation-bridge/es/annotations');

var _digiratiBemJs = require('digirati-bem-js');

var _digiratiBemJs2 = _interopRequireDefault(_digiratiBemJs);

require('./drafts.scss');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

function getImageFromTarget(state, draft, size) {
  var imageService = (0, _manifestQuery.currentImageService)(state);
  if (imageService) {
    var prefix = imageService.split('info.json')[0];
    if (!draft || !draft.selector) {
      return null;
    }
    if (draft.selector.type.toLowerCase() === 'wholecanvasselector') {
      return prefix + 'full/' + size + ',/0/default.jpg';
    }
    return '' + prefix + draft.selector.x + ',' + draft.selector.y + ',' + (draft.selector.width || size) + ',' + (draft.selector.height || size) + '/' + size + ',/0/default.jpg';
  }
  return null;
}

var $style = _digiratiBemJs2.default.block('drafts-list');

var Drafts = function (_Component) {
  _inherits(Drafts, _Component);

  function Drafts() {
    var _temp, _this, _ret;

    _classCallCheck(this, Drafts);

    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return _ret = (_temp = (_this = _possibleConstructorReturn(this, _Component.call.apply(_Component, [this].concat(args))), _this), _this.state = {
      error: null
    }, _temp), _possibleConstructorReturn(_this, _ret);
  }

  Drafts.prototype.getUserName = function getUserName(draft) {
    return draft.fingerprint.creator || 'unknown';
  };

  Drafts.prototype.setError = function setError(message) {
    var _this2 = this;

    this.setState({
      error: message
    });
    setTimeout(function () {
      return _this2.setState({
        error: null
      });
    }, 1500);
  };

  Drafts.prototype.render = function render() {
    var _$style$element$modif,
        _this3 = this;

    var _props = this.props,
        state = _props.state,
        label = _props.label,
        description = _props.description,
        drafts = _props.drafts,
        selectScopedDraft = _props.selectScopedDraft,
        currentDrafts = _props.currentDrafts,
        moveForward = _props.moveForward,
        reset = _props.reset,
        filterBy = _props.filterBy,
        emptyState = _props.emptyState,
        hideIfEmpty = _props.hideIfEmpty,
        _props$showThumbnail = _props.showThumbnail,
        showThumbnail = _props$showThumbnail === undefined ? false : _props$showThumbnail,
        _props$thumbnailSize = _props.thumbnailSize,
        thumbnailSize = _props$thumbnailSize === undefined ? 150 : _props$thumbnailSize,
        isSupportedResource = _props.isSupportedResource;

    var draftList = drafts ? Object.values(drafts) : [];
    var filterByMultiple = filterBy.split(',');
    var filteredDraftLIst = draftList.length ? draftList.filter(function (draft) {
      return !(filterByMultiple && filterByMultiple.indexOf(draft.fingerprint.source) === -1);
    }) : [];
    if (filteredDraftLIst.length === 0 && hideIfEmpty) {
      return null;
    }

    return _react2.default.createElement(
      'div',
      { className: $style },
      label ? _react2.default.createElement(
        'h3',
        { className: $style.element('label') },
        label
      ) : null,
      description ? _react2.default.createElement(
        'p',
        { className: $style.element('description') },
        description
      ) : null,
      this.state.error ? _react2.default.createElement(
        'div',
        { className: $style.element('error') },
        this.state.error
      ) : null,
      _react2.default.createElement(
        'ul',
        { className: $style.element('list').modifiers((_$style$element$modif = { hasThumbnail: showThumbnail }, _$style$element$modif['thumbnail-' + thumbnailSize] = showThumbnail, _$style$element$modif)) },
        filteredDraftLIst.length ? filteredDraftLIst.map(function (draft) {
          var thumbnail = showThumbnail && getImageFromTarget(state, draft, 40);

          return _react2.default.createElement(
            'li',
            { className: $style.element('list-item').modifier({
                'selected': currentDrafts && draft.fingerprint && draft.fingerprint.scope && currentDrafts[draft.fingerprint.scope] === draft.id
              }), key: draft.id, onClick: function onClick() {
                if (draft.fingerprint && draft.fingerprint.scope && draft.fingerprint.path) {
                  if (!isSupportedResource(draft.template)) {
                    _this3.setError('This annotation is not currently available to edit.');
                  } else {
                    if (draft.fingerprint.path.length) {
                      reset(draft.fingerprint.scope);
                      draft.fingerprint.path.forEach(function (forward) {
                        return moveForward(draft.fingerprint.scope, forward);
                      });
                    }
                    selectScopedDraft(draft.fingerprint.scope, draft.id);
                  }
                }
              } },
            showThumbnail && thumbnail ? _react2.default.createElement(
              'div',
              { className: $style.element('thumbnail') },
              _react2.default.createElement('img', { src: getImageFromTarget(state, draft, thumbnailSize) })
            ) : null,
            _react2.default.createElement(_digiratiAnnotationComponents.ActionTimeAgo, { verb: 'Created', subject: _this3.getUserName(draft), time: draft.fingerprint.created }),
            draft.fingerprint.lifecycle === 'DRAFT_LIFECYCLE_CHANGED' ? _react2.default.createElement(
              'span',
              { className: $style.element('unsaved') },
              'unsaved changes'
            ) : null
          );
        }) : _react2.default.createElement(
          'div',
          { className: $style.element('empty-state') },
          emptyState ? emptyState : 'Any annotations you mark as in progress will show here'
        )
      )
    );
  };

  return Drafts;
}(_react.Component);

exports.default = (0, _digiratiAnnotationRedux.connector)(Drafts);
module.exports = exports['default'];